package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(L``````````0```````
M`+%```````!``#@`"`!``!<`%@````8````%`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````&``````````8``````````$````!
M````!0```````````````````````````````````````)[T````````GO0`
M```````0``````$````&````````J[@```````"[N````````+NX````````
M!,`````````5*````````!```````@````8```````"KX````````+O@````
M````N^`````````!H`````````&@``````````AD=.50````!````````)F<
M````````F9P```````"9G`````````"\`````````+P`````````!&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````"KN````````+NX````````N[@````````$
M2`````````1(``````````$O;&EB+VQD+6UU<VPM<S,Y,'@N<V\N,0`````1
M````3`````(````'201`"0@`A9KH`(2*012.2`````````!,````4````%0`
M``!5````6@```%L```!<`````````%X``````````````%\```!@````80``
M````````?)I_:@[OT^HM1][.']_%;[:;Q2X.\8VX?-1DU`[D_R$<6''98&RA
M^BP_Y<)OBP&R`<9'XGR2X[O2/,-59LRO9]-P!XCLU45#[=MB,YN<J7\*`J?A
M2?O@HP```````````````````````````````````````````P``!P``````
M`!BH```````````````,$@````````````````````````````''$@``````
M```````````````````````4$0````````````````````````````'M$0``
M``````````````````````````%I$@`````````````````````````````;
M$@````````````````````````````&F$@``````````````````````````
M```C$@`````````````````````````````J$@``````````````````````
M``````'Z$@````````````````````````````&R$@``````````````````
M```````````S(`````````````````````````````-"(0``````````````
M``````````````!+$@````````````````````````````!1$@``````````
M``````````````````,($@````````````````````````````+Y$@``````
M``````````````````````)_$@````````````````````````````!8$@``
M``````````````````````````(@$@````````````````````````````!?
M$@````````````````````````````*T$@``````````````````````````
M``!F$@````````````````````````````!N(```````````````````````
M``````""$@````````````````````````````*=$@``````````````````
M``````````"*$@````````````````````````````"0$@``````````````
M``````````````"9(`````````````````````````````+R$@``````````
M``````````````````"U$@````````````````````````````"Z$@``````
M``````````````````````(+$0````````````````````````````*[$@``
M``````````````````````````)-$@````````````````````````````,8
M$@````````````````````````````(_$@``````````````````````````
M``.<$@````````````````````````````+&$0``````````````````````
M``````-!$0````````````````````````````)Q$@``````````````````
M``````````,N$@````````````````````````````-#$0``````````````
M``````````````#!$@````````````````````````````,F$@``````````
M``````````````````%W$@````````````````````````````#*(@``````
M``````````````````````#9(`````````````````````````````#O$@``
M``````````````````````````+J$@````````````````````````````)=
M$@````````````````````````````#T$@``````````````````````````
M``#Z(`````````````````````````````*H$@``````````````````````
M``````$4$@````````````````````````````&7$@``````````````````
M``````````$9$@````````````````````````````*-$@``````````````
M``````````````&&$@````````````````````````````$?$@``````````
M``````````````````$P$@````````````````````````````(;$@``````
M``````````````````````"+$@````````````````````````````(L$@``
M``````````````````````````)F$@````````````````````````````,?
M$@````````````````````````````$V$@``````````````````````````
M``,0$@````````````````````````````%*$@``````````````````````
M``````(6$@````````````````````````````'5$@``````````````````
M``````````%1$@````````````````````````````-`(0``````````````
M``````````````%B$@````````````````````````````,[$@``"0``````
M`"!P`````````DP```'G$@``"@```````%H0``````````(```/>$@``"0``
M`````$M0````````"C(```14$@``"0```````%E(`````````&X```.[$@``
M"0```````$3@``````````8```/M$@``!P```````!BH``````````(```0!
M$@``"0```````%6(`````````[P```1'$@``"0```````$3H`````````@@`
M``-2$```%````````,!X``````````````/,$@``"0```````$J8````````
M`+(```/K$@``"0```````$,H`````````#P```/S$@``"0```````$G@````
M`````'(```0A$@``"0```````$;P`````````"(```->$```%````````-#@
M``````````````.!$@``"0```````"+P`````````#0```0N$@``"0``````
M`$<8`````````2P```07$0``$P```````,!P``````````@```-+$```$P``
M`````,!X``````````````-7$@``"0```````"+```````````````.*$@``
M"0```````$I8`````````#H```.E$@``"0```````$/(`````````1@```0Z
M$@``"0```````$A(`````````98`;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R
M<@!R96%L;&]C`&%C8V5S<P!S;G!R:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?
M:6YF;P!L<V5E:P!G971P:60`;65M<V5T`'5N;&EN:P!M96UM;W9E`%]*=E]2
M96=I<W1E<D-L87-S97,`<W1R;F-M<`!L<W1A=`!C;&]S961I<@!?251-7V1E
M<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`<F5A9&QI;FL`7U]C
M>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`
M7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?97)R;F]?
M;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G971S<&5C:69I8P!M96UC<'D`7U]S
M=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T
M7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA
M9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?
M<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O
M;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P
M97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S;"US,SDP>"YS;RXQ
M`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D:7(`<W!R:6YT
M9@!S=')C:'(`<W1R=&]K`'-T<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?
M96YV:7)O;@!?961A=&$`7U]B<W-?<W1A<G0`7V5N9``O=7-R+VQI8B]P97)L
M-2]C;W)E7W!E<FPO0T]210!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE
M8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!M>5]P87)?<&P`<&%R
M7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N=@!P87)?9FEN9'!R
M;V<`<&%R7V-L96%N=7``````````OW@`````````#````````"!P````````
MOY``````````#````````%H0````````O[``````````#````````!BH````
M````P```````````#````````,``````````P`@`````````#````````%RN
M````````P!``````````#````````%J(````````P"``````````#```````
M`%MT````````P"@`````````#````````%MX````````P#``````````#```
M`````%RT````````P#@`````````#````````%K:````````P$``````````
M#````````%R\````````P%``````````#````````%S`````````P%@`````
M````#````````%S&````````P'``````````#````````%UH````````OX``
M```$````"@``````````````````OX@````%````"@``````````````````
MOY@````-````"@``````````````````OZ`````9````"@``````````````
M````OZ@````>````"@``````````````````O[@````B````"@``````````
M````````O\`````H````"@``````````````````O\@````L````"@``````
M````````````O]`````P````"@``````````````````O]@````Q````"@``
M````````````````O^`````V````"@``````````````````O^@````[````
M"@``````````````````O_`````\````"@``````````````````O_@```!!
M````"@``````````````````O9@````"````"P``````````````````O:``
M```#````"P``````````````````O:@````&````"P``````````````````
MO;`````'````"P``````````````````O;@````(````"P``````````````
M````O<`````)````"P``````````````````O<@````*````"P``````````
M````````O=`````+````"P``````````````````O=@````,````"P``````
M````````````O>`````-````"P``````````````````O>@````/````"P``
M````````````````O?`````0````"P``````````````````O?@````1````
M"P``````````````````O@`````2````"P``````````````````O@@````3
M````"P``````````````````OA`````4````"P``````````````````OA@`
M```5````"P``````````````````OB`````6````"P``````````````````
MOB@````7````"P``````````````````OC`````8````"P``````````````
M````OC@````:````"P``````````````````OD`````;````"P``````````
M````````OD@````<````"P``````````````````OE`````=````"P``````
M````````````OE@````?````"P``````````````````OF`````@````"P``
M````````````````OF@````A````"P``````````````````OG`````C````
M"P``````````````````OG@````D````"P``````````````````OH`````E
M````"P``````````````````OH@````F````"P``````````````````OI``
M```G````"P``````````````````OI@````J````"P``````````````````
MOJ`````K````"P``````````````````OJ@````M````"P``````````````
M````OK`````N````"P``````````````````OK@````O````"P``````````
M````````OL`````P````"P``````````````````OL@````Q````"P``````
M````````````OM`````R````"P``````````````````OM@````S````"P``
M````````````````ON`````T````"P``````````````````ON@````U````
M"P``````````````````OO`````W````"P``````````````````OO@````X
M````"P``````````````````OP`````Y````"P``````````````````OP@`
M```Z````"P``````````````````OQ`````]````"P``````````````````
MOQ@````^````"P``````````````````OR`````_````"P``````````````
M````OR@```!`````"P``````````````````OS````!"````"P``````````
M````````OS@```!#````"P``````````````````OT````!$````"P``````
M````````````OT@```!%````"P``````````````````OU````!&````"P``
M````````````````OU@```!'````"P``````````````````OV````!(````
M"P``````````````````OV@```!)````"P``````````````````OW````!+
M````"P``````````Z^_P<``DN00`#Z?[_V#C`/```"3`Y0``!=K`Y0``('OK
M[_$0``0'_N,0\#@`),`0``!25=('\#`0".,0$!``!`?Q!P`'``<`P!```%)4
MXQ`0```$!_$-$.,0$`P`%,#T____Y0````#`$```4DCC$!````0'\0T0XQ`0
M#``4P/3____5````&,`0``!2/.,0$```!`?Q#1#C$!`,`!3`]/___\4````P
MP!```%(PXQ`0```$!_$-$.,0$`P`%,#T____M0```$C`$```4B3C$!````0'
M\0T0XQ`0#``4P/3___^E````8,`0``!2&.,0$```!`?Q#1#C$!`,`!3`]/__
M_Y4```!XP!```%(,XQ`0```$!_$-$.,0$`P`%,#T____A0```)#`$```4@#C
M$!````0'\0T0XQ`0#``4P/3___]U````J,`0``!1].,0$```!`?Q#1#C$!`,
M`!3`]/___V4```#`P!```%'HXQ`0```$!_$-$.,0$`P`%,#T____50```-C`
M$```4=SC$!````0'\0T0XQ`0#``4P/3___]%````\,`0``!1T.,0$```!`?Q
M#1#C$!`,`!3`]/___S4```$(P!```%'$XQ`0```$!_$-$.,0$`P`%,#T____
M)0```2#`$```4;CC$!````0'\0T0XQ`0#``4P/3___\5```!.,`0``!1K.,0
M$```!`?Q#1#C$!`,`!3`]/___P4```%0P!```%&@XQ`0```$!_$-$.,0$`P`
M%,#T___^]0```6C`$```493C$!````0'\0T0XQ`0#``4P/3___[E```!@,`0
M``!1B.,0$```!`?Q#1#C$!`,`!3`]/___M4```&8P!```%%\XQ`0```$!_$-
M$.,0$`P`%,#T___^Q0```;#`$```47#C$!````0'\0T0XQ`0#``4P/3___ZU
M```!R,`0``!19.,0$```!`?Q#1#C$!`,`!3`]/___J4```'@P!```%%8XQ`0
M```$!_$-$.,0$`P`%,#T___^E0```?C`$```44SC$!````0'\0T0XQ`0#``4
MP/3___Z%```"$,`0``!10.,0$```!`?Q#1#C$!`,`!3`]/___G4```(HP!``
M`%$TXQ`0```$!_$-$.,0$`P`%,#T___^90```D#`$```42CC$!````0'\0T0
MXQ`0#``4P/3___Y5```"6,`0``!1'.,0$```!`?Q#1#C$!`,`!3`]/___D4`
M``)PP!```%$0XQ`0```$!_$-$.,0$`P`%,#T___^-0```HC`$```403C$!``
M``0'\0T0XQ`0#``4P/3___XE```"H,`0``!0^.,0$```!`?Q#1#C$!`,`!3`
M]/___A4```*XP!```%#LXQ`0```$!_$-$.,0$`P`%,#T___^!0```M#`$```
M4.#C$!````0'\0T0XQ`0#``4P/3___WU```"Z,`0``!0U.,0$```!`?Q#1#C
M$!`,`!3`]/___>4```,`P!```%#(XQ`0```$!_$-$.,0$`P`%,#T___]U0``
M`QC`$```4+SC$!````0'\0T0XQ`0#``4P/3___W%```#,,`0``!0L.,0$```
M!`?Q#1#C$!`,`!3`]/___;4```-(P!```%"DXQ`0```$!_$-$.,0$`P`%,#T
M___]I0```V#`$```4)CC$!````0'\0T0XQ`0#``4P/3___V5```#>,`0``!0
MC.,0$```!`?Q#1#C$!`,`!3`]/___84```.0P!```%"`XQ`0```$!_$-$.,0
M$`P`%,#T___]=0```ZC`$```4'3C$!````0'\0T0XQ`0#``4P/3___UE```#
MP,`0``!0:.,0$```!`?Q#1#C$!`,`!3`]/___54```/8P!```%!<XQ`0```$
M!_$-$.,0$`P`%,#T___]10```_#`$```4%#C$!````0'\0T0XQ`0#``4P/3_
M__TU```$",`0``!01.,0$```!`?Q#1#C$!`,`!3`]/___24```0@P!```%`X
MXQ`0```$!_$-$.,0$`P`%,#T___]%0``!#C`$```4"SC$!````0'\0T0XQ`0
M#``4P/3___T%```$4,`0``!0(.,0$```!`?Q#1#C$!`,`!3`]/___/4```1H
MP!```%`4XQ`0```$!_$-$.,0$`P`%,#T___\Y0``!(#`$```4`CC$!````0'
M\0T0XQ`0#``4P/3___S5```$F,`0``!/_.,0$```!`?Q#1#C$!`,`!3`]/__
M_,4```2PP!```$_PXQ`0```$!_$-$.,0$`P`%,#T___\M0``!,C`$```3^3C
M$!````0'\0T0XQ`0#``4P/3___RE```$X,`0``!/V.,0$```!`?Q#1#C$!`,
M`!3`]/___)4```3XP!```$_,XQ`0```$!_$-$.,0$`P`%,#T___\A0``!1#`
M$```3\#C$!````0'\0T0XQ`0#``4P/3___QU```%*,`0``!/M.,0$```!`?Q
M#1#C$!`,`!3`]/___&4```5`P!```$^HXQ`0```$!_$-$.,0$`P`%,#T___\
M50``!5C`$```3YSC$!````0'\0T0XQ`0#``4P/3___Q%```%<,`0``!/D.,0
M$```!`?Q#1#C$!`,`!3`]/___#4```6(ZV_P,``DP-```!S]X_#_2/]QXS#P
MJ``DXT#PH``D4"#PM$%`\*!!,/"H02#PM,#E___^:<1(``!/JL0H``!/H[D$
M`#3`Y?___.[$&```3V>5`!``IW0`'L#E___]Q,0K``!8!>PF``@`?*<I``'`
MY?___GG`Y?___M;$&```3V?C(!```!;`Y?___TV2`"DAQ+@``$]<XR"P```6
MP.7___]"E@(D^N,@L```%L#E____.E@0\+26`23Z["$`!0#8XQ#0```$N10`
M(NPA``S`9<0X``!/0,`@```==<#E___\4NLB``,`#<#E___^?.,P\*@`!.,0
M,```!.,0(```),`0```=^.,0(`@`),08``!/>N,0(!``),`0```=[N,0(!@`
M)%A`\+3`$```5Y@21.5,$```!*<8``&Y\B`4Q"L``%>)03`P"*<(``&G%@!L
M[!0`!`#8N10`$>L1``,`#>,1+_C_<;D$`%+E2!````"G2@`#IVD``+D4`$3`
M,```$+[$*```5W/`Y?___,P8LNPF``H`?L0H``!7:<#E___^`ABRQ"@``%=B
MP.7___UKP"```!R#P.4```W!["8`(@!\P!```%=/XQ`0```"IW0`"\`@```<
M2L#E```-L,0K``!70<`0``!7/N,0$````J>$``C$*```5S;`Y0``&V_$*```
M5S3`Y?___KW`Y?__^UJY%``KXT#Q*``$ZV_PZ``$!_3L4``$`-CCL#````2Y
M%`!5IPH``>M5``,`#:<[``CCM2_X_R2G]/^"!P<'![D$`"_`,````!+C,#``
M`!BG^_]@IPD``.,`\```),#T````"0<'!P<``)CX!P<'!^MO\#``).,P(`0`
M%./P_UC_<4%`(`CE2/"@``#`8```&X+`4/__^LO`(/___JS`Y?___/D'!P<'
MP!```$ZHP"```$ZE01`0![D)`!+L'``*#GW$&```3C/L&``$`'P'\0?^!P<'
M!P<'P#```$Z0P!```$Z-N>D0$^L1``,`"NLQ`#\`#+D(`#'K,P`!``KL.``-
M`'S$&```3B[L&``'`'S`(```3G0'\0?^!P<'!P<'P!```$YLE0`0``=^ZZ_P
M4``DP!```$X/X_#_8/]QXQ`0```"IX0`",0H``!.',#E___\X<"P``!+^L"@
M``!+^[D)`*OKJ@`#``JGJ___Q!@``$Y)[*$`("!EP.7___^7P!```$W,XQ`0
M```"IX0`",`@```[),#E___Z_<`0``!.+N-`\1``!)(!$`#KK_#P``0']*<;
M``'$&P``3B3K$0`#``WC$;````0-X:?T_]'K[_!P`"3C\/]@_W'C0/$0``3K
M[_$0``0']`<'!P<'!^OO\'``),`0``!-L>/P_V#_<>,0$````J>$``O`,```
M3?[`(```.N/`Y?___(S`(```2YWC$"````*GA``)Q!@``$UY[!@`!`!\#>'K
M[_$0``3`]/___TOK[_!P`"3C\/]@_W'C0/$0``3K[_$0``0']`<'!P<'![)/
M`!#K$0`@``VR3P`1ZV_P,``DIUD`"./P_-#_<=('\R@0*$&@(#A!$/"HI[D`
M`+D$`#'C2Z````3K!``@``SC`#```"3`2@````#C0#`(`"2GNP`(ISL`$*=7
M_^U!0/*HXS`0:``$XS`00`""XS`0$`""XS`0``""[%,@OV%5[%,@/@%6XU`0
M@``DIQL`".Q!_^E@9.,0\*@`!,(:6H)YF>,0("``".,P(```!..`(!``!.,`
M(`@`!.-0(!@`!.RC(+]E5>QP(+]^5>RC(#H%5NQP("$>5KD(`*&YYW"XN>=0
M&+F``+.Y@``0N8(`N+F"`!7LTR"_?E6Y"`"A[-,@(1Y6[$H@OP!5XQ#PL``$
MN8``K<(:6H)YF>MD``(`#+D(`!7L9"`A'E:Y"``;Z[0`&P`,[+0@.@56N0@`
ML>R;(+\`5;F``+:G&?__N><0%*=)__^Y@``7N>=`2;F!`!JY@`!-XZ#PN``$
MN8$`2\*J6H)YF>.P\,``!+D(`*C"NEJ">9FY"`"AN0@`>[D(`'3K&0`;``SL
M&2`Z!5:Y"``:[*$@OP!5ZTH`&P`,[$H@.@56N0@`1^MY``(`#.QY("$>5KF`
M`!>GF?__N>>0FKF``):Y@0"1XQ#PR``$PAI:@GF9N0@`T;D(`-GLM""_`%7K
MFP`;``SLFR`Z!5:Y"`"=Z]H``@`,[-H@(1Y6N8``3:>I__^YYZ"KN8``I[F!
M`*3C0/#0``3"2EJ">9FY"`!DN0@`:NP9(+\`5>NA`!L`#.RA(#H%5KD(`*;K
M:P`"``SL:R`A'E:Y@`"6I[G__[GGL+&Y@`"]N8$`N>.0\-@`!,*:6H)YF>Q*
M(+\`5;D(`'GKD0`"``SLD2`A'E:Y@`"IN0@`>Z<9__^YYQ`4N8``%KF!`!KC
MH/#@``3"JEJ">9FY"`#:N0@`T>NT`!L`#.RT(#H%5KD(`+?L>R"_`%7K%P`;
M``SL%R`Z!5:Y"``=Z]0``@`,[-0@(1Y6N8``O:=)__^YYT!'N8``2;F!`$OC
ML/#H``3"NEJ">9FY"`!KN0@`9.RA(+\`5>M*`!L`#.Q*(#H%5KD(`$;K9P`"
M``SL9R`A'E:Y@``6IWG__[GG<'JY@`!]N8$`<>,0\/``!,(:6H)YF;D(`)&Y
M"`"7[+0@OP!5ZWL`&P`,['L@.@56N0@`>>N:``(`#.R:("$>5KF``$FGJ?__
MN>>@J[F``*:Y@0"DXT#P^``$PDI:@GF9N0@`U+D(`-KL%R"_`%7KH0`;``SL
MH2`Z!5:Y"`"MZ]L``@`,[-L@(1Y6N8``?:>Y__^YY["QN8``N;F!`+?C</$`
M``3">EJ">9GL2B"_`%6Y"`!GZW$``@`,['$@(1Y6N8``I[D(`&NG&?__N><0
M%+F``!VY@0`:XZ#Q"``$PJI:@GF9N0@`FKD(`)'KM``;``SLM"`Z!5:Y"`"V
M[&L@OP!5ZQ8`&P`,[!8@.@56N0@`&>N4``(`#.R4("$>5KF``+FG2?__N>=`
M1KF``$>Y@0!+X[#Q$``$PKI:@GF9N0@`V[D(`-3LH2"_`%7K2@`;``SL2B`Z
M!5:Y"`!-Z]8``@`,[-8@(1Y6N8``':=I__^YYV!JN8``:;F!`&'C$/$8``3"
M&EJ">9FY"`!QN0@`=NRT(+\`5>MK`!L`#.QK(#H%5KD(`&?K>@`"``SL>B`A
M'E:Y@`!'IZG__[GGH*NY@`"MN8$`I.-`\2``!,)*6H)YF;D(`)2Y"`":[!8@
MOP!5ZZ$`&P`,[*$@.@56N0@`J>N;``(`#.R;("$>5KF``&FGN?__N>>PL;F`
M`+>Y@0"VXV#Q*``$PFI:@GF9N0@`UKD(`-OL2B"_`%7KM``;``SLM"`Z!5:Y
M"`"]Z]$``@`,[-$@(1Y6N8``K:<9__^YYQ`4N8``&;F!`!KCH/$P``3"JEJ"
M>9FY"`!ZN0@`<>QK(+\`5>L6`!L`#.P6(#H%5KD(`!?K=``"``SL="`A'E:G
M2?__N8``M[GG0$:Y@`!-N8$`2^RA(+\`5>.P\3@`!,*Z6H)YF;D(`)NY"`"4
MZTH`&P`,[$H@.@56N0@`2>-`\*``).R4(+\`5>NV`!X`#:=)___K9@`"``RY
MYT!*N8``1[F!`+;L:R"_`%6Y@``6N8$`%.-`\4``!,)*6H)YF;D(`-3K2@`>
M``WKJ@`"``RY@0"DN8(`NN-`\*``!+F"`$OCL/%(``3"NF[9ZZ&Y"`![Z[D`
M'@`-N0@`T>L9`!L`#.P9(#H%5NN9``(`#+D(`!VY@0";N>>0NKF"`+'LT2"_
M`%6Y&@!TXQ#Q4``$N00`1\(:;MGKH;D(`!:Y&@`;Z[T`'@`-ZWT`&P`,['T@
M.@56Z]T``@`,N0@`=+F!`-OL1R"_`%7CL/%8``3"NF[9ZZ&Y&@"ZN>?0J;F"
M`'JY&@"WZW0`'@`-ZV0`&P`,[&0@.@56ZT0``@`,N8$`1^-P\6``!,)Z;MGK
MH;D:`'FY"`!AN00`J^P6(+\`5;D$`)>YYT!]N8(`9[D:`);KL0`;``RY!`!Y
M[+$@.@56N0@`NNRK(+\`5>N:`!L`#.R:(#H%5NMA`!X`#;D(`)?L>2"_`%7K
M$0`"``RY@0`6XV#Q:``$PFINV>NAN1H`;;GG$-2Y@@"]Z]H`'@`-ZZH``@`,
MN8$`K>/0\7``!,+:;MGKH;D:`-2Y!`!-N>>@T;F"`)WKUP`>``VY&@!KZ[<`
M&P`,[+<@.@56ZW<``@`,N8$`?>/0\7@`!,+:;MGKH;D:`-&Y!``=N>=PVKD(
M`+:Y&@!)[&L@OP!5N8(`O>O6`!X`#;D$`)3K1@`;``SL1B`Z!5;K9@`"``RY
M@0!MX]#Q@``$PMINV>NAN1H`VKD$`*VYYV#7N0@`2;D:`!OLE""_`%6Y@@!-
MZ]D`'@`-N00`L>L9`!L`#.P9(#H%5NN9``(`#+F!`)WCT/&(``3"VF[9ZZ&Y
M&@#7N00`?;GGD-:Y"``;[+$@OP!5N8(`'>O;`!X`#;D:`*3K2P`;``SL2R`Z
M!5;KNP`"``RY@0"]X]#QD``$PMINV>NAN1H`UKD$`&VYY[#9N0@`2NRD(+\`
M5;F"`$WKV@`>``VY&@!QZQH`&P`,[!H@.@56ZZH``@`,N8$`K>/0\9@`!,+:
M;MGKH;D:`-FY!`"=N>>@V[D(`!?L<2"_`%6Y@@`=Z]<`'@`-N1H`9.M'`!L`
M#.Q'(#H%5NMW``(`#+F!`'WCT/&@``3"VF[9ZZ&Y&@#;N00`O;GG<-JY"`!&
M[&0@OP!5N8(`3>O6`!X`#;D:`)'K%@`;``SL%B`Z!5;K9@`"``RY@0!MX]#Q
MJ``$PMINV>NAN1H`VKD$`*VYYV#7N0@`&>R1(+\`5;F"`!WKV0`>``VY&@"T
MZTD`&P`,[$D@.@56ZYD``@`,N8$`G>/0\;``!,+:;MGKH;D:`->Y!`!]N>>0
MUKD(`$OLM""_`%6Y@@!-Z]L`'@`-N1H`H>L;`!L`#.P;(#H%5NN[``(`#+F!
M`+WCT/&X``3"VF[9ZZ&Y&@#6N00`;;GGL-FY"``:[*$@OP!5N8(`'>O:`!X`
M#;D:`'3K2@`;``SL2B`Z!5;KJ@`"``RY@0"MX]#QP``$PMINV>NAN1H`V;D$
M`)VYYZ#;N0@`1^QT(+\`5;F"`$WKUP`>``VY&@!AZQ<`&P`,[!<@.@56ZW<`
M`@`,N8$`?>/0\<@`!,+:;MGKH;D:`-NY!`"]N>=PVKD(`!;L82"_`%6Y@@`=
MZ]8`'@`-N1H`E.M&`!L`#.Q&(#H%5NMF``(`#+F!`&WCT/'0``3"VF[9ZZ&Y
M&@#:N00`K;GG8->Y"`!)[)0@OP!5N8(`3>O9`!X`#;D:`+'K&0`;``SL&2`Z
M!5;KF0`"``RY@0"=X]#QV``$PMINV>NAN1H`U[D$`'VYYY#6N0@`&^RQ(+\`
M5;F"`!WKVP`>``VY&@"DZTL`&P`,[$L@.@56Z[L``@`,N8$`O>/0\>``!,+:
M;MGKH;D:`-:Y!`!MN>>PV;D:`'&Y"`!*[*0@OP!5N8(`3>L:`!L`#.O:`!X`
M#>P:(#H%5KD(`!?KJ@`"``SL<2"_`%6Y@0"MN>:@V[F``-&YY*`;N8$`T;D:
M`&3C$/'H``3K1P`;``S"&H\;O-SL1R`Z!5:Y&@`9N0@`1KD:`!WKUP`>``WL
M9""_`%7K=P`"``RY@0!]N>9PVKF``-2YY'!*N8$`U+D$`)'C0/'P``3K%@`;
M``S"2H\;O-SL%B`Z!5:Y&@!+N0@`&;D:`$WKU@`>``WLD2"_`%7K9@`"``RY
M@0!MN>9@U[F``-&YY&`7N8$`T;D$`+3C$/'X``3K20`;``S"&H\;O-SL22`Z
M!5:Y&@`:N0@`2[D:`!WKV0`>``WLM""_`%7KF0`"``RY@0"=N>:0UKF``-2Y
MY)!&N8$`U+D$`*'C0/(```3K&P`;``S"2H\;O-SL&R`Z!5:Y&@!'N0@`&KD:
M`$WKVP`>``WLH2"_`%7KNP`"``RY@0"]N>:PV;F``-&YY+`9N8$`T;D$`'3C
M$/((``3K2@`;``S"&H\;O-SL2B`Z!5:Y&@`6N0@`1[D:`!WKV@`>``WL=""_
M`%7KJ@`"``RY@0"MN>:@V[F``-2YY*!+N8$`U+D$`&'C0/(0``3K%P`;``S"
M2H\;O-SL%R`Z!5:Y&@!)N0@`%KD:`$WKUP`>``WL82"_`%7K=P`"``RY@0!]
MN>9PVKF``-&YY'`:N8$`T;D$`)3C$/(8``3K1@`;``S"&H\;O-SL1B`Z!5:Y
M&@`;N0@`2;D:`!WKU@`>``WLE""_`%7K9@`"``RY@0!MN>9@U[F``-2YY&!'
MN8$`U+D$`+'C0/(@``3K&0`;``S"2H\;O-SL&2`Z!5:Y&@!*N0@`&[D:`$WK
MV0`>``WLL2"_`%7KF0`"``RY@0"=N>:0UKF``-&YY)`6N8$`T;D$`*3C$/(H
M``3K2P`;``S"&H\;O-SL2R`Z!5:Y&@`7N0@`2KD:`!WKVP`>``WLI""_`%7K
MNP`"``RY@0"]N>:PV;F``-2YY+!)N00`<;F!`-3C0/(P``3"2H\;O-RY&@!&
MN1H`3;D$`&3KV@`>``WK&@`;``SL&B`Z!5:Y"``7['$@OP!5ZT<`&P`,[$<@
M.@56N0@`1NQD(+\`5>NJ``(`#+F!`*VYYJ#;N8``T;GDH!NY@0#1XQ#R.``$
MPAJ/&[S<N1H`&;D:`!WKUP`>``WK=P`"``RY@0!]N>9PVKF``-2YY'!*N8$`
MU+D$`)'C0/)```3K%@`;``S"2H\;O-SL%B`Z!5:Y&@!+N0@`&;D:`$WKU@`>
M``WLD2"_`%7K9@`"``RY@0!MN>9@U[F``-&YY&`7N8$`T;D$`+3C$/)(``3K
M20`;``S"&H\;O-SL22`Z!5:Y&@`:N0@`2[D:`!WKV0`>``WLM""_`%7KF0`"
M``RY@0"=N>:0UKF``-2YY)!&N8$`U+D$`*'C0/)0``3K&P`;``S"2H\;O-SL
M&R`Z!5:Y&@!'N0@`&KD:`$WKVP`>``WLH2"_`%7KNP`"``RY@0"]N>:PV;F`
M`-&YY+`9N8$`T;D$`'3C$/)8``3K2@`;``S"&H\;O-SL2B`Z!5:Y&@`6N0@`
M1[D:`!WKV@`>``WL=""_`%7KJ@`"``RY@0"MN>:@V[F``-2YY*!+N8$`U+D$
M`&'C0/)@``3K%P`;``S"2H\;O-SL%R`Z!5:Y&@!)N0@`%KD:`$WKUP`>``WL
M82"_`%7K=P`"``RY@0!]N>9PVKF``-&YY'`:N8$`T;D$`)3C$/)H``3K1@`;
M``S"&H\;O-SL1B`Z!5:Y&@`;N0@`2;D:`!WKU@`>``WLE""_`%7K9@`"``RY
M@0!MN>9@U[F``-2YY&!'N8$`U+D$`+'C0/)P``3K&0`;``S"2H\;O-SL&2`Z
M!5:Y&@!*N0@`&[D:`$WKV0`>``WLL2"_`%7KF0`"``RY@0"=N>:0UKF``-&Y
MY)`6N8$`T;D$`*3C$/)X``3K2P`;``S"&H\;O-SL2R`Z!5:Y&@`7N0@`2KD:
M`!WKVP`>``WLI""_`%7KNP`"``RY@0"]N>:PV;F``-2YY+!)N8$`U.-`\H``
M!,)*CQN\W+D:`$:Y&@!-Z]H`'@`-N00`<>L:`!L`#.P:(#H%5NNJ``(`#+F!
M`*WCT/*(``3"VLIBP=:Y&@#9N00`G;GGH-NY"``7['$@OP!5N8(`'>O7`!X`
M#;D$`&3K1P`;``SL1R`Z!5;K=P`"``RY@0!]X]#RD``$PMK*8L'6N1H`V[D$
M`+VYYW#:N0@`1NQD(+\`5;F"`$WKU@`>``VY&@"1ZQ8`&P`,[!8@.@56ZV8`
M`@`,N8$`;>/0\I@`!,+:RF+!UKD:`-JY!`"MN>=@U[D(`!GLD2"_`%6Y@@`=
MZ]D`'@`-N1H`M.M)`!L`#.Q)(#H%5NN9``(`#+F!`)WCT/*@``3"VLIBP=:Y
M&@#7N00`?;GGD-:Y"`!+[+0@OP!5N8(`3>O;`!X`#;D:`*'K&P`;``SL&R`Z
M!5;KNP`"``RY@0"]X]#RJ``$PMK*8L'6N1H`UKD$`&VYY[#9N0@`&NRA(+\`
M5;F"`!WKV@`>``VY&@!TZTH`&P`,[$H@.@56ZZH``@`,N8$`K>/0\K``!,+:
MRF+!UKD:`-FY!`"=N>>@V[D(`$?L=""_`%6Y@@!-Z]<`'@`-N1H`8>L7`!L`
M#.P7(#H%5NMW``(`#+F!`'WCT/*X``3"VLIBP=:Y&@#;N00`O;GG<-JY"``6
M[&$@OP!5N8(`'>O6`!X`#;D:`)3K1@`;``SL1B`Z!5;K9@`"``RY@0!MX]#R
MP``$PMK*8L'6N1H`VKD$`*VYYV#7N0@`2>R4(+\`5;F"`$WKV0`>``VY&@"Q
MZQD`&P`,[!D@.@56ZYD``@`,N8$`G>/0\L@`!,+:RF+!UKD:`->Y!`!]N>>0
MUKD(`!OLL2"_`%6Y@@`=Z]L`'@`-N1H`I.M+`!L`#.Q+(#H%5NN[``(`#+F!
M`+WCT/+0``3"VLIBP=:Y&@#6N00`;;GGL-FY"`!*[*0@OP!5N8(`3>O:`!X`
M#;D:`''K&@`;``SL&B`Z!5;KJ@`"``RY@0"MX]#RV``$PMK*8L'6N1H`V;D$
M`)VYYZ#;N0@`%^QQ(+\`5;F"`!WKUP`>``VY&@!DZT<`&P`,[$<@.@56ZW<`
M`@`,N8$`?>/0\N``!,+:RF+!UKD:`-NY!`"]N>=PVKD(`$;L9""_`%6Y@@!-
MZ]8`'@`-N1H`D>L6`!L`#.P6(#H%5NMF``(`#+F!`&WCT/+H``3"VLIBP=:Y
M&@#:N00`K;GG8->Y"``9[)$@OP!5N8(`'>O9`!X`#;D:`+3K20`;``SL22`Z
M!5;KF0`"``RY@0"=X]#R\``$PMK*8L'6N1H`U[D$`'VYYY#6N0@`2^RT(+\`
M5;F"`$WKVP`>``VY&@"AZQL`&P`,[!L@.@56Z[L``@`,N8$`O>/0\O@`!,+:
MRF+!UKD:`-:Y!`!MN>>PV;D(`!KLH2"_`%6Y@@`=Z]H`'@`-N1H`=.M*`!L`
M#.Q*(#H%5NNJ``(`#+F!`*WCT/,```3"VLIBP=:Y&@#9N00`G;GGH-NY&@!A
MN0@`1^QT(+\`5;F"`$WKUP`>``VY&@"4ZQ<`&P`,[!<@.@56ZW<``@`,N0@`
M%KF!`'WL82"_`%7CT/,(``3K1@`;``S"VLIBP=;L1B`Z!5:Y&@#;N0@`2>R4
M(+\`5;D$`+VYYW#:N8(`'>O6`!X`#>MF``(`#+F!`&WCT/,0``3"VLIBP=:Y
M&@#:N00`K;GG8->Y@@!-Z]D`'@`-N1H`L>L9`!L`#.P9(#H%5NN9``(`#+F!
M`)WCT/,8``3"VLIBP=:Y&@#7N00`?;GGD-:Y&@"DN0@`&^RQ(+\`5;F"`!WC
MT/,@``2Y&@!QPMK*8L'6N1H`UNM+`!L`#+D$`&WL2R`Z!5:Y"`!*[*0@OP!5
MZQH`&P`,[!H@.@56N0@`%^M[`!X`#<`:`````.N[``(`#+F!`+>YY[#9N8(`
M3;D(``&Y&@!DP`H`````XP`@"``DZT$`&P`,N1H`6^Q!(#H%5L!:`````.-0
M(!@`)+D(`$;C$"`@``2Y&@`TN1H`&<`Z`````.,P(```),`:`````.,0("``
M).MZ``(`#.QZ("$>5KD(`(?`B@````#C@"`0`"2R3P`0ZQ$`(``-LD\`$=4'
M\R@0**>$``7`Y?__\:OC0/.@``3K;_-@``0']`<'ZV_P,``DX_#_8/]Q["@`
M40!\Q!@``$%CXV`0```"IX0`2+D$`$+C$$```)3L%@`V`'X;0KD$`(*Y!`!S
MN00`IKD4`+3CD*````*GA``>N00`2[D$`#CC(*````3`Y?__[Q+L)@`B`'Y!
M&Y``E3T0`*=T`!NY"0"F09N0`>NJ``,`"E"@<`"Y!``IXT#Q$``$ZV_PT``$
M!_3L&/_-/7Y!0$`!I_3_PD&@H`BG]/_-IYD``*?T_^H'!^OO\'``)+)/`!#K
M$0`@``VR3P`1X_#_4/]Q03#PI-('\*@0*,#E____DK)/`!#K$0`@``VR3P`1
MU0?PJ!`HIX0`!<#E___Q(^-`\2``!.OO\2``!`?T!P?KK_!0`"2R3P`0X_#_
M4/]QZQ$`(``-LD\`$;D$`++2!_"H$"A!H/"DN00`.KD$`"O`Y?___V#L)@`2
M`'RR3P`0ZQ$`(``-LD\`$=4'\*@0**>$`![`Y?__\.[C$/"D`!3$*```0+3K
M$0`#``WC$"````CC(!`(``3C(!```"3L*/_5`'Q!$!`(I_3_]>-`\2``!.NO
M\0``!`?T!P<'!P<'ZV_P,``DP-````W)X_#_4/]QLD\`$.L1`"``#;)/`!&Y
M!`"SIP@``-('\*@0*.,0,```E*<X``#`%P```#VY^Q`3X[#0``"(IZD``+D$
M`)*Y!``;03#PI+)>`*&G%/_^N0D`J\#E___^]NPH`#$`?*<(``"G&0``N00`
M,K)>`!.G%/_^N0D`$NRA`)$@9:<9``#C,;```)!",2``IQL``>PV__D`?*<H
M``"R3P`0ZQ$`(``-LD\`$=4'\*@0*+D4`"*GA`#.P.7___!EQ!@``$`NXW`0
M```$IQD``!B!IQL``>LA``,`#>,B?_C_`J=T__?`$```2)/C$!```!*GA``<
M[#@``@#8N00`)[D4`#/K,P`#``W`Y?__[,W$&```0`;C(!```"3L)@`M`'RG
M*/__I_3_O,`0``!(<>PH``(`V.5,$````;D4`"+K(@`#``W`Y?__[9^Y!`!B
M["C_Z0!\N10`2+D$`#?K1``#``W`Y?__[:#$&```/]GC8!```"2Y%``8Q"@`
M`#_1IQL``>,@(```!.L1``,`#4$1(`#E2!````!0@/"DN00`&>,@$```E.PF
M`$<`?KD)`!GL*@`"`-FY&``AQ(@``#^PXW#PI``4ZW<``P`-XW"````(P.7_
M_^U8XR!P```D["C_H0!\XQ#PI``4XR"````$ZQ$``P`-XQ$@```$XR"0``"0
M0B`0`$&0D`&YE``B["8`&@!^DCT0`*<I``#C,K```)!",A`!IRL``>PV__D`
M?*?T_S3L*/^\/7Y!$!`!I_3_L>PH_^D]?D$0$`&G]/_8XU#Q(``$ZV_PX``$
M!_4'!P<'ZW_P.``DLD\`$./P_LC_<>L1`"``#;)/`!'2!_$P$"CL*``E`'RY
M!`"BE0`@`*>$`![`Y?__Z]>Y!`""["@`%P!\07#PH+D$`"C`Y?__[(OL)@`<
M`'RY!``HP.7__^TSN00`*L#E___NGK)/`!#K$0`@``VR3P`1U0?Q,!`HIX0`
M;L#E___O3T&P(!/`$```#':G"```N00`*[)=`!*G%/_^IX3_TL`0```,:KD$
M`"NR70`2IQ3__J>$_\>Y!``:IRD``+)>`"&G%/_^N00`.Z<9``"R7@`3IQ3_
M_KD)`!NY"0`J&B&G*@`"N10`(L#E___LF<`P```,1;D$`)*Y!`!;N00`2L#E
M___NS;D$`#>Y!``IP.7__^Z&["@`&?]^6!#PN*<H0`#`&P``\`#L$@`/8':Y
M!``IP.7___]DN00`*<#E___N7Z?T_W^Y!``IP.7__^Q8I_3_].-`\:@`!.M_
M\7``!`?TZZ_P4``DX_#_8/]QN00`HL2X```^F.,@L```%L#E___N?NPR`@``
MV;D$`"K`Y?__[(;L*``.`'ZG*```N10`(N-`\1``!.NO\/``!`?TXR"P```6
MP.7__^YB6!`B&*<H0`#`&P``\`#L$@`18':G.0`"N00`*L#E___K41`BIRK_
M_X@@`!^G]/_;XR"P```6P.7__^Y$6!`B&*4OH`#`&P``\`#L$O_*8':G]/_B
M!P?K[_!P`"3$&```/D7C\/]@_W'C(!```!;`Y?__[BC`4```"YG$2```/D[`
M,```"Z'K[_$0``3`]/__[?D'!P<'ZV_P,``DX_#_6/]QQ+@``#XBXR"P```6
MP&````SOP.7__^X%P.7____.XR"P```6P.7__^W\N00`5N5(\*```,!````(
M\,`P```+@<#E___K#N-`\1@`!.MO\-@`!`?TZV_P,``DLD\`$./P_U#]<>L1
M`"``#>,@\*@"<;)/`!'2!R``$"C`Y?__ZS%!L/"FN00`4L!@```+9<!````+
M9*<Y$`&Y!``KP.7__^K0["8`&?]^I[D``+)/`!#C,/"H`G'K$0`@``VR3P`1
MN00`*]4',``0**>$`$K`Y?__[??L(!``(''L)/_G`'[CH/"G`7&G21``N00`
M.KD$`"O`Y?__[&6Y!`""["3_U@!^IRH``;D4`"+`Y?__ZUFY!`"R["C_R@!\
MN10`F.PJ``>@94$9(`"Y84"A[+H`!\!E01F@`+EA0+'L@!`!('*Y!`!)N00`
M.KD$`"O`Y?__[8A!&;``D@`0`*?T_ZGC0/$@`@3K;_#@`@0'],#T____=`<'
MZV_P,``DLD\`$./P_U#^<;D$`++K$0`@``WC(/"H`7&R3P`1N00`@]('(``0
M*,`@```*X,#E___\1J<Y`"^Y!`"2N00`*\#E___KL>PH`!\`?+D$`#O`(```
M"M'`Y?___*ZR3P`0XS#PJ`%QZQ$`(``-LD\`$;D$`"O5!S``$"BGA`"]P.7_
M_^UBIP@``+D$`!NY!``HIZD``,`P```*MK)>`*&G%/_^P-````I\&ZM!@/"H
MIZH``<#E___LZ.PH_\H`?)4`(`"YXH`M[)@`&0!\IP@``+D$`!*Y!``YLET`
M$Z<4__ZG=``,P#````J.IRD``,#E___LRJ?T_^*G"```IQD``+D$`#*R7@`3
MIQ3__AL2N10`,>,S+___<94O,`"GA``C&AJG.`__[!/_DR!VX[#PH``DN00`
M4L!@```*9L!````*U:<Y$`"Y!``HP.7__^F\IQ@0`*<J``'L(0`/P'>G]``!
MIQK__[D4`#%!,R``D@`P`*?T_\[$>```/*KC('```!;`Y?__[)#L,@(``-FY
M!``HP.7__^Q8[";_I@!^XR!P```6P.7__^Q_6!`B&*4O@`#`&P``\`#L$O^6
M8':G.0`!N00`*,#E___I;NPF_XP`?KD$`#C`(```"@[`Y?__^^NY!``HP.7_
M_^J.N00`LJ?T_S;C0/$@`03K;_#@`00']$$0(`'C,!___Y3L-@`$`'X'_J<^
M`"^YXH`AIQL``:?T__,'!P<'!P?L*``)`'SC4"```)3L5@`)`'[`(```":_`
M]/__ZF"Y!``RIP@``*<9``"R7@`3IQ3__N-`'___<;GI(#'L)``&(&7L)@`%
M_WRG.0`!IS<`$NPD`"Q@9.Q8_]XO?L`@```)OJ?T_]OC0$___W&G]/_PE2]`
M`*>$__FYZ2`4XS!/__]QN2$`(Z<Y``&YXC`3I_0`">-`3___<:<7``2G]/_:
ME2]``*=T__>YZ2`4XS!/__]Q[",`!B!E["8`!?]\IQD``>-`3___<:<7``^Y
M"0!"ISD0`.P4``(`V>P3``S`9:<I```'_I4O0`"GA/_LI_3_[^OO\'``)*=+
M``'C\/]@_W&Y!``R[$`0`"!QP"```#Q*P.7__^J3P"```#Q$XT#Q$``$Z^_Q
M$``$!_0'!P<'Z^_P<``DLD\`$.L1`"``#;)/`!'C\/\P_W'`(```"4C2!_#(
M$"C`$```".G2(?"F$`#`Y?__^L/`(```"3[`Y?__^KW`(```"3S`Y?__^K?`
M(```"3O`Y?__^K'`(```"3G`Y?__^JO`(```"3O`Y?__^J7`(```"0W`Y?__
M^I_`(```"37`Y?__^IG`(```"33`Y?__^I/`(```"3/`Y?__^HW`(```"/K`
MY?__^H?`(```"2S`Y?__^E7L*``+`'RY!``RP"````D7P.7___K&P"````DD
MP.7___I$["@`"P!\N00`,L`@```)(L#E___ZM<`@```)(L#E___Z,^PH`",`
M?+D$`#+`(```",+`Y?__^J3`,```"<[`(```"-G`Y?__^INR3P`0ZQ$`(``-
MLD\`$=4'\,@0**>$`";`Y?__ZU3`(```"0'`Y?__^@KL*``*`'RY!``RP"``
M``C'I_3_UZ=)``K`,```"/A!(/"WP.7__^C:[";_S@!^03#PP:?T_^SC0/%`
M``3K[_%```0']`<'Q!T``#M$IQ[__Z=T`##K[_!P`"3`(```")_C\/]@_W'`
MY?__^=3L*``>`'SC$"```)#L&``8`'S`%P```#"Y`P`1ZQ$`/P`,Q!\``#L@
MXT#Q$``$Q"P``#L:Z^_Q$``$!_2G&```I_3_\<0L```[#P?^!P<'!P<'Z^_P
M<``DX_#_8/]QP.7__^KVP.7__^DS["@`#0!\XR`@```$XT#Q$``$Z^_Q$``$
M!_2G*0``I_3_]P<'!P<'!^MO\#``)+D$`++C\/]@_W'`(```"(/`Y?__^7VY
M!``[["@`"0!\N00`8I4`(`"G=``+P"````ARZV_PT``$P/3___GEP.7__^BJ
M["8`+0!\IP@``+D$`!NR7@`AIQ3__KD$`#:G&0``LEX`$Z<4__ZY"0`6N0D`
M*T$B$`+`Y?__Z`[`,```"%VY!`"BP%````?EN00`2\#E___J0;D$`#JG]/_)
MXT#Q$``$ZV_PT``$!_0'!P<'!P?K;_`P`"3`T```!XFY!`#OX_#^`/=QI^O_
MX&"`X`!@H.`(8,#@$&#@X!BR3P`0ZQ$`(``-LD\`$;D$`*+C(/'8"''2!R``
M$"C`$```.CC2%_"X$`#`$```.C[2+_#H$`#`$```.E#2%_#0$`#`(```!XW`
MY?__^//L*``G`'RY!`"RE0`@`*>$`"#`Y?___U^Y!``KP.7__^@&N00`@K)/
M`!#C,/'8"''K$0`@``VR3P`1N00`*-4',``0**>$!*C`Y?__ZA#`Y?___R'L
M)@#;`'Q!D/#0XQ"0```"IW0`!\"P```'QZ?T`!GC()````3`Y?__^+3L*`#"
M`'R5`"``IX0`O<#E___GSKD$`+*GFP`([+C_X@!\IP@``+D$`!NG*0``LEX`
M(:<4__ZY"0`KZR(``0`-IRL``<#E___G4[D$`)*Y!`""XT"P``"4[$8`G@!^
M0;#PZ..`L````J>$`![C(+````3`Y?__^'BY!`""["@`G`!\E0`@`*>$`)?`
MY?__^M3L*`"2`'ZY!``HP.7__^>(N00`@D&P\+CLA@`,`'SC<+````*GA``&
ME0!P`*=T`("G"```N00`&*>Y``"R7@"QIQ3__KD$`"FG&0``LEX`$J<4__ZY
M"0`9N0D`N!JQI[H$!+D4`+NY!``KP&````=&P.7__^;UXY#PH``DN00`<L`P
M```'/L!0```&RKD$`$C`Y?__Z26G.0'`N00`)\#E___HONPF`%C_?L#E___H
MJ-4#T``@`*>$`$_CL*````3`Y?__Z)W$&```./+C8"```!2Y!`!7N00`2\`P
M```'%N,@$```!,#E___H&J>)``"G]/\4I[D``*?T_TBY!`"RI_3_2;D$`"BY
M%`!$P#````;R0;"P`4&`@`+`Y?__Z."G]/]1I[L`"*?T_U7C(+````3`Y?__
M^CCL*``*`'ZY!``GP.7__^;LN00`@J>[``BG]/]DQ(@``#C'XR"````6P.7_
M_^BM[#("``#9N00`)\#E___FM1B2["8#=`!^XR"````6P.7__^B;6!`B&*<H
M0`#`&P``\`#L$@-D8';C((```!;`Y?__Z(M88"(<P.7__^CF[&(#5F!VXR"`
M```6P.7__^A]6!`B&*<H`<#`&P```?_L$@-&8':Y!``KP.7__^8^N00`@L`@
M```&R\#E___W<NPH`!4`?..PH```!,#E___FC;D$`#*Y!``KP.7___L"N00`
MLNPF``8`?..PH```!*<(``"G&0``N00`*[)>`!*G%/_^N0D`&^P<`$(#?KD4
M`"'C,K_\_W'`(```!GNR70`CIQ3__J=T`#/L&``.!'ZG&O_\N10`$>,1O___
M<94O$`"G=``EXR"@"``"IX0`(*<(``"G&0``N00`,K)>`!.G%/_^N0D`$NP<
M`!(#?>,A+_S_<<`0```&4+)=`!*G%/_^IW0`!>.PH`@`!,#E___])>PF`GD`
M?KD$`"NG.0``P.7__^8SN00`LABB["@";`!^ITD``J<Y_^Y!8/'8P.7__^4T
MITD`!KD$`#:Y!``KP.7__^=+E0#QV*=T`$^50_'9IW0`2Y5!\=JG=`!'E4/Q
MVZ=T`$.52/'<IW0`/Y5%\=VG=``[ITD``J<Y_\:Y!``KP.7__^4*ITD`*;D$
M`#:Y!``KP.7__^<AP!````:5P%````5;XQ#PH``DN00`1\`P```%[;D$`"C`
MY?__YZZY!``GP.7__^=9N00`.,`@```%-\#E___W&;D$`"C`Y?___1"G]/VX
MITD``*<Y``"Y!``KP.7__^31P!%G12,!XQ#Q&``DP!_OS:N)XQ#Q(``DP!^8
MNMS^XQ#Q*``DP!$0,E1VXQ#Q,``DP!_#TN'PXQ#Q.``DN10`&N5(\4```+/!
M`('E2/%(``!!$/$8Y4SQD```L\$`H;/-`"BE3X``N00`-D&0\5#`Y?__YK?C
M(/"P`"18H/"T[*(`Z@!^L\T`*$%@\1C`Y?__YHCCL/%```3CH/%(``3L&SJ_
M?57L00`!`-BY%``101'Q4)*`$`"Y%``D[$P!E#A^IQ@`0*<Y``"Y^4!!02*0
M`+D4`$3`Y?__Y+2Y!``FP.7__^F[ITD`.*<Y``"Y!``IIYD``,#E___DI$*@
M\8M"L/&/ZQH`&``,0A#QB.L:`!``#$(0\8GK&@`(``Q"$/&*ZQL`&``,0A#Q
MC.L;`!``#$(0\8WK&P`(``Q"$/&.N00`)D&P\:^GJ0`4N00`:\#E___I@^,0
M\1@`!$(0\9[K(0`8``Q"(/&;ZR$`$``,0B#QG.LA``@`#$(@\9WC$/$@``1"
M$/&BZR$`&``,0B#QG^LA`!``#$(@\:#K(0`(``Q"(/&AXQ#Q*``$0A#QINLA
M`!@`#$(@\:/K(0`0``Q"(/&DZR$`"``,0B#QI>,0\3``!.LA`!@`#$(@\:="
M$/&JZR$`$``,0B#QJ.LA``@`#$(@\:GC$/$X``3K(0`8``Q"(/&KZR$`$``,
M0A#QKD(@\:SK(0`(``Q!$/&;0B#QK;/!`(&SS0`8N00`*\`P```$@^-)$```
MD*>[``*GFP`!P.7__^9NIZ?_[Y(`\=>G]/ZIXS#Q0``$XR#PM``4ZQ(``P`-
MN0@`$\`:`````.PQ``;`9>L!\4@`>N,0\4``).LB`!T`#.,@\4@`".,@\4@`
M).,0\9``$J>$`'M8(/"TIZ@`0!NA&2JY\L"BN00`*;D8`"&Y%`"Z["8`"*!E
M01L@`.QA``M`9>PF``K`94$;8`#L(0`%H&6G]``!I1^``.RQ__P@9;D$`$NY
M!``VP.7__^8G&!I:$/&04!#QD.P6_K!`?K/-`"I8$/"T&QI!NV``&*'`Y?__
MZ*!!$/&0L\$`X>L:``8`WNPA``$`V!*J&!*G*``!N?*@(5`@\+!8$/"PIQK_
M_U`0\+"G=``FN10`2NRY``C`94$4D`#LL?^^0&7LN0`(H&5!%+``[)'_MD!E
M[$+_LTA]N00`.[D$`"G`Y?__Y=Y0H/&0I_3^:KD$`+:G]/_$[+D`",!EL\T`
M'NRQ_YQ`94$0L$"SP0#![+D`!J!E[)'_DD!EN00`.Z=)`$"Y!``IL\T`O*>J
M_\#`Y?__Y;>SS0`JP.7__^@^I_3_L*<8`#BG.0``N?E`04$BD`"Y%`!$I_3^
M?<`P```$-L`@```#3\"P```$8L#E___U`,#E___BU<`0```$6;D$`&+C$/"@
M`"3`4````QJY!`!'P#````.WN00`*,#E___E<*<Y`<"Y!``HP.7__^4)[";]
MN_]^P.7__^3SU0/0`"``IW3]LJ>:``'`Y?__XJFY%``9N00`8N.P\*@`).,0
M\*``),!0```"[+D$`$?`,````Y"Y!``HP.7__^5"I_3_TL08```U);D$`%?C
M0*````3`,````XKC(!````3`Y?__Y$^G]/PU[8#QX`AE[:#QZ`AE[<#Q\`AE
M[>#Q^`AEXT#R<`@$ZV_R,`@$!_0'!P<'!P?K?_`X`"3C\/]@_W'$N```-1+C
M(+```!;`Y?__Y/BY!`"BXR"P```6P.7__^3PT@"@N2"XP"````*MP.7___/S
M["@`"P!\E3$@`*=T``:5`"`!IX0`!<#E___Y-<08```TZN,@$```%L#E___D
MT*=9``NG20`!P#````-IP.7__^,V["8`40!\Q*@``#34XR"@```6P.7__^2Z
MIUD``Z=)``'`,````U;`Y?__XR"Y!`"R["8`N@!\Q)@``#2\XR"0```6P.7_
M_^2BIUD``Z=)``'`,````T+`Y?__XPBY!`"R["@`[0!\P"````(XP.7___.9
MN00`HNPH`,0`?.,@D```%L#E___D@N,0L!``!+D$`$KC,!````3`Y?__XP>G
M]`#.XQ`@$``$IZ@``.-P$"@`!.RZ``$`V,:]```]`Z>D`!G$B```-';C((``
M`!;`Y?__Y%RG60``N10`2KD$`#?`Y?__X>.Y!`"2["8`)`!\Q!T``#SGIQK_
M_^RA_X9@=J>X``'&O0``/-VGI/]^Q!@``#10XR`0```6I[H``<#E___D-+D$
M`#?`Y?__X.^G]/_KQ!@``#S"N10`NZ<X!`#KNP`#``WCNQ````3C$"````18
M(!`,P"L`(`0`[",`$F!VXR`0$``$IP@``+)=`"NG%/_^IW3_OJ>J``&G]/^;
MXR"````6P.7__^0`IUD``J=)``#C,)````3`Y?__Y#:G]/_DXR"@```6P.7_
M_^/NXQ"P$``$P$````*,XS`0```$P.7__^)RXQ"P$``$XQ`0```$D4`0#:>$
M_R_C(*```!;`Y?__X]+C$+`0``3C,!````3`Y?__X7FG]/\>P.7___7@N00`
MHN,@D```%NRH`%\`?,#E___CN>,0L!``!+D$`$KC,!````3`Y?__XCZY!``J
MP.7__^-IQ+@``#.ZXR"P```6P.7__^.@N00`HN,@L```%L#E___CF*=)``'`
M,````CO`Y?__X(#`0````D"Y!``RN00`*L#E___B%N,@L```%L#E___C@)(`
M(+G`(````1[`Y?__\H3$*P``/!7L)@`C`'S$*```/`?`Y?__^4S$*P``/`GL
M)@`7`'S`(````AG`Y?__X)#`Y?__XUW$.```._+C$+`0``3C0#````2G]/[7
MISD!P,0H```[[<#E___B^NPH`!H1?NP2``$`V.P<`!0!?\08```[UKD$`%+$
M2```.]GC,!````3`(````?K`Y?__X&#C0/$0``3K?_#8``0']`<'!P?KK_!0
M`"3C\/]@_W&Y!`"RP.7___;@P.7___;)N00`HL#E___X/.PH`!T`?NRX`!H`
M?)4`L`"GA``5P#````$EN00`*L#E___A4NRB``M@9+D$`"OKK_#P``3`]/__
M\[?C0/$0``3KK_#P``0']`<'Z[_P6``DX_#_8/]QP+```##ZXQ"P```$[!8`
M"O]\XT#Q$``$Z[_P^``$!_0-X>.PO_C_<:?T_^_K[_!P`"3C\/]@_W'C0/$0
M``3K[_$0``0']`<'!P<'!^OO\'``)+D$``^G^_]@XP#P```DP.7__^2^Z^_Q
M$``$!_X``````````````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@```````````````1`````!__________<&5R;'AS:2YC````````
M`"X`+BX``"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E
M<FYA;',Z.E!!4CHZ0D]/5```97AE`"]P<F]C+R5I+R5S`%!!4E]414U0``!0
M05)?4%)/1TY!344``#H`+P!015),-4Q)0@``4$523$Q)0@!015),-4]05```
M4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.
M`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P``4$%27T=,
M3T)!3%]435!$25(`4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'
M3$]"04Q?0TQ%04X``%!!4E]#3$5!3CT``$Q$7TQ)0E)!4EE?4$%42`!365-4
M14T``"4P,G@``'!A<BT``"5S)7,E<R5S```E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``!P87)L
M```N<&%R```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P`E<R5S=&5M
M<"TE=2TE=25S``!0051(```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*```O=&UP``!414U01$E2`%1-4`!54T52``!54T523D%-10``
M05)'5@``&`!P97)L```P`%!!4CHZ4&%C:V5R.CI615)324].```Q+C`T,0!5
M;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@``+64``"TM``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3
M("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE
M('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G
M;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE
M<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD
M:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]
M/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP
M<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P
M,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@
M)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD
M*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F
M;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.
M('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA
M;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S
M97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@
M("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G
M+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P
M87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A
M;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R
M;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@
M/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@
M/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K
M(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D
M(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D
M<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X
M(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^
M/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P
M,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O
M9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A
M9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B
M3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F
M(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO
M=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X
M="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F
M:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D
M969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M
M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,
M24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U
M;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65]
M(#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN
M86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C
M:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U
M;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[
M)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH
M)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE
M(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE
M+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@
M(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T
M=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@
M9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M
M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF
M("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M
M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP
M,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S
M<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;
M,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C
M;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@
M=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*
M:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@
M0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE
M;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,[
M"G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU
M<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D
M9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E
M("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I
M9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q
M(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q
M)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D
M;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z
M("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#([
M"GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI
M('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I
M<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`
M05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI
M=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U
M="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I
M;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P
M,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I
M;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM
M>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B([
M"F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U
M;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U
M="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ
M3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD
M+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968[
M"G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII
M9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A
M?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I
M"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L
M(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V
M86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H
M)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B
M/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S
M970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<[
M"GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD
M;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM
M>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N
M92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X
M<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@
M0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R
M.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT
M(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R
M96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*
M9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS
M:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>
M+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y
M.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D
M;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL
M97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL
M92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O
M;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB
M=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#
M86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT
M(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI
M.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O
M)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N
M86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I
M*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I
M;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D
M8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M
M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W
M('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U
M+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(
M03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D
M;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P
M96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T
M>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA
M;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI
M.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E
M.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P
M96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB
M0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP
M.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!
M4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@
M:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M
M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@
M;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@[
M"FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z
M.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I
M.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M
M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA
M;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI
M.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@
M=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE
M9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/
M(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D
M,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N
M<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=
M('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D
M,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M
M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M
M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D
M;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A
M=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@
M9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I
M<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*
M<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R
M<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U
M:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N
M9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S
M.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@
M?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U
M:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4
M:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L
M24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@
M=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD
M<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH
M;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!4
M14U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N
M;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@[
M"FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E
M='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN
M,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.
M86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D
M<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\
M("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O
M7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB
M+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA
M;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@
M-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#([
M"G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS
M92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG
M97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I
M;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@
M*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U
M+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T
M>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O
M9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*
M8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D[
M"GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[
M4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY
M("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE
M(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2![
M"FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@
M)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z
M("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E
M("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E
M.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M
M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O
M<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M
M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD
M<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C
M:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?
M9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*
M<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D
M0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)
M04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?
M24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%
M04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L
M971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#
M3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'
M3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT[
M"GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM0
M05)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#
M3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@
M;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A
M;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T
M=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?
M7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@
M>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA
M<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB
M97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD
M;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H
M:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A
M<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B
M)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE
M<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I
M(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D
M0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I
M(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``1L#.P``
M`+@````6__^&U```!13__XM,````U/__HU0```$4__^D#````53__Z1D```!
M=/__I00```&D__^G=````>3__ZC<```"'/__J8P```),__^IS````FS__ZHL
M```"K/__JT0```+L__^K3````P3__ZU4```#1/__K7P```-<__^NK````X3_
M_[!$```#K/__L+P```/<__^P_```!`3__[&T```$5/__N^P```2<__^_K```
M!-0````4``````%Z4@`!>`X!&PP/H`$````````\````'/__BG```!@&`%B&
M#H<-B`R)"XH*BPF,"(T'C@:/!48.T`<#%^;/SLW,R\K)R,?&#J`!````````
M````/````%S__Z(X````M@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#L`"`HH*
MS\[-S,O*R<C'Q@Z@`4(+`````````!P```"<__^BL````%8`5(X&CP5&#M`"
M>L_.#J`!````+````+S__Z+H````F@!*B@J+"8P(C0>.!H\%1@[0`@*(S\[-
MS,O*#J`!````````/````.S__Z-8```";`!&A@Z'#8@,B0N*"HL)C`B-!XX&
MCP5,#M`"`P)8S\[-S,O*R<C'Q@Z@`0```````````#0```$L__^EB````6@`
M2H<-B`R)"XH*BPF,"(T'C@:/!48.V`,#`5;/SLW,R\K)R,<.H`$`````+```
M`63__Z:X````K@!&B@J+"8P(C0>.!H\%1@[``@)`"L_.S<S+R@Z@`4(+````
M'````93__Z<X````/`!,C@:/!48.P`)DS\X.H`$````\```!M/__IU@```!@
M`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.R`("4L_.S<S+RLG(Q\8.H`$`````
M````````/````?3__Z=X```!&`!*A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M!"
M`P$&S\[-S,O*R<C'Q@Z@`0```````````!0```(T__^H4`````8`````````
M`````#P```),__^H0````@@`2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[0(@,!
M]L_.S<S+RLG(Q\8.H`$````````````4```"C/__J@@````B````````````
M```D```"I/__JA@```$L``+\C@:/!48.P`)HS\X.H`$`````````````)```
M`LS__ZL@```!E@!4C@:/!48.\`(#`7K/S@Z@`0```````````"P```+T__^L
MD````'(`6HX&CP5&#L`"`D`*S\X.H`%""T@.H`'.SP```````````"0```,D
M__^LV````#H`1HX&CP5&#L`"9`K/S@Z@`4(+``````````!,```#3/__K/``
M``"R`$:&#H<-B`R)"XH*BPF,"(T'C@:/!4H.P`)N"L_.S<S+RLG(Q\8.H`%&
M"P)LS\[-S,O*R<C'Q@Z@`0```````````$0```.<__^M6```"C(`1H8.APV(
M#(D+B@J+"8P(C0>.!H\%4`Z@A0)4F!B9%YH6FQ4#"@;/SLW,R\K)R,?&V]K9
MV`Z@`0```#0```/D__^W2````[P`1H<-B`R)"XH*BPF,"(T'C@:/!48.P`(#
M`Z[/SLW,R\K)R,<.H`$`````/```!!S__[K0````;@!&B@J+"8P(C0>.!H\%
M1@[``@)."L_.S<S+R@Z@`48+3,_.S<S+R@Z@`0```````````#P```1<__^!
MN````DP`1H8.APV(#(D+B@J+"8P(C0>.!H\%3`[8`@,"$`K/SLW,R\K)R,?&
M#J`!0@L`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/______
M____``````````#__________P```````````````````````````````0``
M```````!``````````$````````"U0`````````/`````````V,`````````
M#````````!BH``````````T```````!:$`````!O__[U`````````A@`````
M````!0````````P(``````````8````````"V``````````*````````!&``
M````````"P`````````8`````````!4````````````````````#````````
MO8```````````@````````6@`````````!0`````````!P`````````7````
M````$P@`````````!P```````!!H``````````@````````"H``````````)
M`````````!@`````````&````````````````&____L`````"````0````!O
M___Y``````````X`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````+O@`````````````````````````````!C^````````&1X`````
M```9/@```````!E>````````&7X````````9G@```````!F^````````&=X`
M```````9_@```````!H>````````&CX````````:7@```````!I^````````
M&IX````````:O@```````!K>````````&OX````````;'@```````!L^````
M````&UX````````;?@```````!N>````````&[X````````;W@```````!O^
M````````'!X````````</@```````!Q>````````''X````````<G@``````
M`!R^````````'-X````````<_@```````!T>````````'3X````````=7@``
M`````!U^````````'9X````````=O@```````!W>````````'?X````````>
M'@```````!X^````````'EX````````>?@```````!Z>````````'KX`````
M```>W@```````![^````````'QX````````?/@```````!]>````````'WX`
M```````?G@```````!^^````````']X````````?_@```````"`>````````
M(#X````````@7@```````"!P`````````````````````````````%H0````
M````````````````````````````````````&*@`````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#``````````%RN````````6H@`````````````
M`````%MT````````6W@```````!<M````````%K:````````7+P`````````
M`````````%S`````````7,8``````````/____\`````````````76A'0T,Z
M("A!;'!I;F4@-BXT+C`I(#8N-"XP```N<VAS=')T86(`+FEN=&5R<``N9VYU
M+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN
M:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M
M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S
M`"YC;VUM96YT````````````````````````````````````````````````
M```````````````````````````````````````````````````+`````0``
M```````"`````````@`````````"```````````8````````````````````
M`0``````````````$V____8``````````@````````(8`````````A@`````
M````O`````,```````````````@``````````````!T````+``````````(`
M```````"V`````````+8````````"3`````$`````@`````````(````````
M`!@````E`````P`````````"````````#`@````````,"`````````1@````
M`````````````````0``````````````+0````0``````````@```````!!H
M````````$&@````````"H`````,```````````````@`````````&````#<`
M```$`````````$(````````3"````````!,(````````!:`````#````$@``
M```````(`````````!@```!!`````0`````````&````````&*@````````8
MJ``````````H`````````````````````@``````````````/`````$`````
M````!@```````!C0````````&-`````````'H`````````````````````0`
M````````(````$<````!``````````8````````@<````````"!P````````
M.:`````````````````````(``````````````!-`````0`````````&````
M````6A````````!:$``````````B`````````````````````@``````````
M````4P````$``````````@```````%HX````````6C@````````_9```````
M``````````````@``````````````%L````!``````````(```````"9G```
M`````)F<`````````+P````````````````````$``````````````!I````
M`0`````````"````````FE@```````":6`````````2<````````````````
M````"```````````````<P````$``````````P```````+NX````````J[@`
M````````$`````````````````````@``````````````'H````!````````
M``,```````"[R````````*O(`````````!`````````````````````(````
M``````````"!`````0`````````#````````N]@```````"KV``````````(
M````````````````````"```````````````A@````8``````````P``````
M`+O@````````J^`````````!H`````0```````````````@`````````$```
M`(\````!``````````,```````"]@````````*V``````````H``````````
M```````````(``````````@```"4`````0`````````#````````P```````
M``"P``````````!X````````````````````"```````````````F@````@`
M`````````P```````,!X````````L'@````````0:```````````````````
M``@``````````````)\````!`````````#```````````````````+!X````
M`````!H````````````````````!``````````$````!`````P``````````
M``````````````````"PD@````````"H`````````````````````0``````
#````
